pub struct CloseBundledPositionInstructionArgs {
pub bundle_index: u16,
}Fields
bundle_index: u16Trait Implementations
Sourceimpl BorshDeserialize for CloseBundledPositionInstructionArgswhere
u16: BorshDeserialize,
impl BorshDeserialize for CloseBundledPositionInstructionArgswhere
u16: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CloseBundledPositionInstructionArgswhere
u16: BorshSerialize,
impl BorshSerialize for CloseBundledPositionInstructionArgswhere
u16: BorshSerialize,
Sourceimpl Clone for CloseBundledPositionInstructionArgs
impl Clone for CloseBundledPositionInstructionArgs
Sourcefn clone(&self) -> CloseBundledPositionInstructionArgs
fn clone(&self) -> CloseBundledPositionInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CloseBundledPositionInstructionArgs
impl PartialEq for CloseBundledPositionInstructionArgs
Sourcefn eq(&self, other: &CloseBundledPositionInstructionArgs) -> bool
fn eq(&self, other: &CloseBundledPositionInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CloseBundledPositionInstructionArgs
impl StructuralPartialEq for CloseBundledPositionInstructionArgs