pub struct InitializeCycloneWithLiquidityCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for InitializeCycloneWithLiquidity via CPI.
Accounts:
[]metadata_program[]vortex_config[writable, signer]token_mint_a[]token_mint_b[writable]metadata[]collect_lp_fees_authority[writable, signer]funder[writable]cyclone[writable, signer]token_vault_a[writable, signer]token_vault_b[]associated_token_program[]cyclone_fee_tier[]token_program[]system_program[]rent
Implementations
Sourceimpl<'a, 'b> InitializeCycloneWithLiquidityCpiBuilder<'a, 'b>
impl<'a, 'b> InitializeCycloneWithLiquidityCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn metadata_program( &mut self, metadata_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn vortex_config(&mut self, vortex_config: &'b AccountInfo<'a>) -> &mut Self
pub fn token_mint_a(&mut self, token_mint_a: &'b AccountInfo<'a>) -> &mut Self
pub fn token_mint_b(&mut self, token_mint_b: &'b AccountInfo<'a>) -> &mut Self
Sourcepub fn metadata(&mut self, metadata: &'b AccountInfo<'a>) -> &mut Self
pub fn metadata(&mut self, metadata: &'b AccountInfo<'a>) -> &mut Self
CHECK : this is safe because we dont read or write from this account
pub fn funder(&mut self, funder: &'b AccountInfo<'a>) -> &mut Self
pub fn cyclone(&mut self, cyclone: &'b AccountInfo<'a>) -> &mut Self
pub fn token_vault_a(&mut self, token_vault_a: &'b AccountInfo<'a>) -> &mut Self
pub fn token_vault_b(&mut self, token_vault_b: &'b AccountInfo<'a>) -> &mut Self
pub fn associated_token_program( &mut self, associated_token_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn cyclone_fee_tier( &mut self, cyclone_fee_tier: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_program(&mut self, token_program: &'b AccountInfo<'a>) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn rent(&mut self, rent: &'b AccountInfo<'a>) -> &mut Self
pub fn name(&mut self, name: String) -> &mut Self
pub fn symbol(&mut self, symbol: String) -> &mut Self
pub fn uri(&mut self, uri: String) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult