pub struct InitializePaymasterFeeConfigInstructionArgs {
pub update_authority: Pubkey,
pub fee_options: [FeeOption; 5],
}Fields
fee_options: [FeeOption; 5]Trait Implementations
Sourceimpl BorshDeserialize for InitializePaymasterFeeConfigInstructionArgs
impl BorshDeserialize for InitializePaymasterFeeConfigInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for InitializePaymasterFeeConfigInstructionArgs
impl Clone for InitializePaymasterFeeConfigInstructionArgs
Sourcefn clone(&self) -> InitializePaymasterFeeConfigInstructionArgs
fn clone(&self) -> InitializePaymasterFeeConfigInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for InitializePaymasterFeeConfigInstructionArgs
impl PartialEq for InitializePaymasterFeeConfigInstructionArgs
Sourcefn eq(&self, other: &InitializePaymasterFeeConfigInstructionArgs) -> bool
fn eq(&self, other: &InitializePaymasterFeeConfigInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InitializePaymasterFeeConfigInstructionArgs
impl StructuralPartialEq for InitializePaymasterFeeConfigInstructionArgs