pub struct InitializePoolInstructionArgs {
pub vortex_bump: u8,
pub tick_spacing: u16,
pub initial_sqrt_price: u128,
}Fields
vortex_bump: u8tick_spacing: u16initial_sqrt_price: u128Trait Implementations
Sourceimpl BorshDeserialize for InitializePoolInstructionArgs
impl BorshDeserialize for InitializePoolInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for InitializePoolInstructionArgs
impl Clone for InitializePoolInstructionArgs
Sourcefn clone(&self) -> InitializePoolInstructionArgs
fn clone(&self) -> InitializePoolInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for InitializePoolInstructionArgs
impl PartialEq for InitializePoolInstructionArgs
Sourcefn eq(&self, other: &InitializePoolInstructionArgs) -> bool
fn eq(&self, other: &InitializePoolInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InitializePoolInstructionArgs
impl StructuralPartialEq for InitializePoolInstructionArgs