pub struct OpenPositionWithMetadataInstructionArgs {
pub position_bump: u8,
pub metadata_bump: u8,
pub tick_lower_index: i32,
pub tick_upper_index: i32,
}Fields
position_bump: u8metadata_bump: u8tick_lower_index: i32tick_upper_index: i32Trait Implementations
Sourceimpl BorshDeserialize for OpenPositionWithMetadataInstructionArgs
impl BorshDeserialize for OpenPositionWithMetadataInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for OpenPositionWithMetadataInstructionArgs
impl Clone for OpenPositionWithMetadataInstructionArgs
Sourcefn clone(&self) -> OpenPositionWithMetadataInstructionArgs
fn clone(&self) -> OpenPositionWithMetadataInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for OpenPositionWithMetadataInstructionArgs
impl PartialEq for OpenPositionWithMetadataInstructionArgs
Sourcefn eq(&self, other: &OpenPositionWithMetadataInstructionArgs) -> bool
fn eq(&self, other: &OpenPositionWithMetadataInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for OpenPositionWithMetadataInstructionArgs
impl StructuralPartialEq for OpenPositionWithMetadataInstructionArgs