pub struct RouteExactInInstructionArgs {
pub route_plan: Vec<RoutePlanStep>,
pub in_amount: u64,
pub quoted_out_amount: u64,
pub slippage_bps: u16,
pub platform_fee_bps: u8,
}Fields
route_plan: Vec<RoutePlanStep>in_amount: u64quoted_out_amount: u64slippage_bps: u16platform_fee_bps: u8Trait Implementations
Sourceimpl BorshDeserialize for RouteExactInInstructionArgswhere
Vec<RoutePlanStep>: BorshDeserialize,
u64: BorshDeserialize,
u16: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for RouteExactInInstructionArgswhere
Vec<RoutePlanStep>: BorshDeserialize,
u64: BorshDeserialize,
u16: BorshDeserialize,
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RouteExactInInstructionArgswhere
Vec<RoutePlanStep>: BorshSerialize,
u64: BorshSerialize,
u16: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for RouteExactInInstructionArgswhere
Vec<RoutePlanStep>: BorshSerialize,
u64: BorshSerialize,
u16: BorshSerialize,
u8: BorshSerialize,
Sourceimpl Clone for RouteExactInInstructionArgs
impl Clone for RouteExactInInstructionArgs
Sourcefn clone(&self) -> RouteExactInInstructionArgs
fn clone(&self) -> RouteExactInInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RouteExactInInstructionArgs
impl Debug for RouteExactInInstructionArgs
impl Eq for RouteExactInInstructionArgs
impl StructuralPartialEq for RouteExactInInstructionArgs