pub struct SetDefaultCycloneBondingCurveInstructionArgs {
pub initial_cyclone_tick_index: i32,
pub final_cyclone_tick_index: i32,
pub liquidity: u128,
pub tokens_sold_threshold: u64,
pub graduation_lower_tick_index: i32,
}Fields
initial_cyclone_tick_index: i32final_cyclone_tick_index: i32liquidity: u128tokens_sold_threshold: u64graduation_lower_tick_index: i32Trait Implementations
Sourceimpl BorshDeserialize for SetDefaultCycloneBondingCurveInstructionArgs
impl BorshDeserialize for SetDefaultCycloneBondingCurveInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SetDefaultCycloneBondingCurveInstructionArgs
impl Clone for SetDefaultCycloneBondingCurveInstructionArgs
Sourcefn clone(&self) -> SetDefaultCycloneBondingCurveInstructionArgs
fn clone(&self) -> SetDefaultCycloneBondingCurveInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for SetDefaultCycloneBondingCurveInstructionArgs
impl PartialEq for SetDefaultCycloneBondingCurveInstructionArgs
Sourcefn eq(&self, other: &SetDefaultCycloneBondingCurveInstructionArgs) -> bool
fn eq(&self, other: &SetDefaultCycloneBondingCurveInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetDefaultCycloneBondingCurveInstructionArgs
impl StructuralPartialEq for SetDefaultCycloneBondingCurveInstructionArgs