pub struct SetProtocolAndCreatorFeeRateInstructionArgs {
pub protocol_fee_rate: u16,
pub creator_fee_rate: u16,
}Fields
protocol_fee_rate: u16creator_fee_rate: u16Trait Implementations
Sourceimpl BorshDeserialize for SetProtocolAndCreatorFeeRateInstructionArgswhere
u16: BorshDeserialize,
impl BorshDeserialize for SetProtocolAndCreatorFeeRateInstructionArgswhere
u16: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetProtocolAndCreatorFeeRateInstructionArgswhere
u16: BorshSerialize,
impl BorshSerialize for SetProtocolAndCreatorFeeRateInstructionArgswhere
u16: BorshSerialize,
Sourceimpl Clone for SetProtocolAndCreatorFeeRateInstructionArgs
impl Clone for SetProtocolAndCreatorFeeRateInstructionArgs
Sourcefn clone(&self) -> SetProtocolAndCreatorFeeRateInstructionArgs
fn clone(&self) -> SetProtocolAndCreatorFeeRateInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for SetProtocolAndCreatorFeeRateInstructionArgs
impl PartialEq for SetProtocolAndCreatorFeeRateInstructionArgs
Sourcefn eq(&self, other: &SetProtocolAndCreatorFeeRateInstructionArgs) -> bool
fn eq(&self, other: &SetProtocolAndCreatorFeeRateInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetProtocolAndCreatorFeeRateInstructionArgs
impl StructuralPartialEq for SetProtocolAndCreatorFeeRateInstructionArgs