pub struct Tick {
pub initialized: bool,
pub liquidity_net: i128,
pub liquidity_gross: u128,
pub fee_growth_outside_a: u128,
pub fee_growth_outside_b: u128,
pub reward_growths_outside: [u128; 3],
}Fields
initialized: boolliquidity_net: i128liquidity_gross: u128fee_growth_outside_a: u128fee_growth_outside_b: u128reward_growths_outside: [u128; 3]Trait Implementations
Sourceimpl BorshDeserialize for Tickwhere
bool: BorshDeserialize,
i128: BorshDeserialize,
u128: BorshDeserialize,
[u128; 3]: BorshDeserialize,
impl BorshDeserialize for Tickwhere
bool: BorshDeserialize,
i128: BorshDeserialize,
u128: BorshDeserialize,
[u128; 3]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Tick
impl BorshSerialize for Tick
Sourceimpl From<Tick> for TickFacade
impl From<Tick> for TickFacade
impl Eq for Tick
impl StructuralPartialEq for Tick