pub struct SwapCycloneCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for SwapCyclone via CPI.
Accounts:
[]token_program[signer]token_authority[writable]cyclone[writable]token_owner_account_a[writable]token_vault_a[writable]token_owner_account_b[writable]token_vault_b[]oracle[optional]program_signer
Implementations
Sourceimpl<'a, 'b> SwapCycloneCpiBuilder<'a, 'b>
impl<'a, 'b> SwapCycloneCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn token_program(&mut self, token_program: &'b AccountInfo<'a>) -> &mut Self
pub fn cyclone(&mut self, cyclone: &'b AccountInfo<'a>) -> &mut Self
pub fn token_owner_account_a( &mut self, token_owner_account_a: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_vault_a(&mut self, token_vault_a: &'b AccountInfo<'a>) -> &mut Self
pub fn token_owner_account_b( &mut self, token_owner_account_b: &'b AccountInfo<'a>, ) -> &mut Self
pub fn token_vault_b(&mut self, token_vault_b: &'b AccountInfo<'a>) -> &mut Self
pub fn oracle(&mut self, oracle: &'b AccountInfo<'a>) -> &mut Self
Sourcepub fn program_signer(
&mut self,
program_signer: Option<&'b AccountInfo<'a>>,
) -> &mut Self
pub fn program_signer( &mut self, program_signer: Option<&'b AccountInfo<'a>>, ) -> &mut Self
[optional account]
The signer for Fogo Sessions token program CPIs
pub fn amount(&mut self, amount: u64) -> &mut Self
pub fn other_amount_threshold( &mut self, other_amount_threshold: u64, ) -> &mut Self
pub fn sqrt_price_limit(&mut self, sqrt_price_limit: u128) -> &mut Self
pub fn amount_specified_is_input( &mut self, amount_specified_is_input: bool, ) -> &mut Self
pub fn a_to_b(&mut self, a_to_b: bool) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult